@@ -2,13 +2,16 @@
 #'
 #' @description This function creates a prior distribution for Bayesian audit sampling according to several methods discussed in Derks et al. (2020). The returned object is of class \code{jfaPrior} and can be used with associated \code{print()} and \code{plot()} methods. \code{jfaPrior} objects can be used as input for the \code{prior} argument in other functions.
 #'
+#' For more details on how to use this function see the package vignette:
+#' \code{vignette("jfa", package = "jfa")}
+#'
 #' @usage auditPrior(confidence = 0.95, likelihood = "binomial", method = "none", 
 #'            expectedError = 0, N = NULL, materiality = NULL, ir = 1, cr = 1,
 #'            pHmin = NULL, pHplus = NULL, factor = 1, sampleN = 0, sampleK = 0)
 #' 
 #' @param confidence      the confidence level desired from the confidence bound (on a scale from 0 to 1). Defaults to 0.95, or 95\% confidence.
 #' @param likelihood      can be one of \code{binomial}, \code{poisson}, or \code{hypergeometric}. See the Details section for more information.
-#' @param method          the method by which the prior distribution is constructed. Defaults to the \code{arm} method, which uses the audit risk model (Derks et al., 2019). Can be one of \code{none}, \code{median}, \code{hypotheses}, \code{arm}, \code{sample} or \code{factor}. See the Details section for more information.
+#' @param method          the method by which the prior distribution is constructed. Defaults to the \code{none} method, which incorporates no prior information. Can be one of \code{none}, \code{median}, \code{hypotheses}, \code{arm}, \code{sample} or \code{factor}. See the Details section for more information.
 #' @param expectedError   a fraction representing the percentage of expected mistakes in the sample relative to the total size, or a number (>= 1) that represents the number of expected mistakes.
 #' @param N               the population size (only required when \code{likelihood = 'hypergeometric'}).
 #' @param materiality     a value between 0 and 1 representing the materiality of the audit as a fraction of the total size or value. Can be \code{NULL} for some methods.
@@ -20,8 +23,6 @@
 #' @param sampleN         When using method \code{sample} or \code{factor}, the number of transactions that were inspected in the previous sample.
 #' @param sampleK         When using method \code{sample} or \code{factor}, the total taint in the previous sample.
 #' 
-#' @details This section elaborates on the available methods for constructing a prior distribution.
-#' 
 #' @details This section elaborates on the available likelihoods and corresponding prior distributions for the \code{likelihood} argument.
 #' 
 #' \itemize{
@@ -30,6 +31,8 @@
 #'  \item{\code{hypergeometric}:   The hypergeometric likelihood is used as a likelihood for record sampling \emph{without} replacement. Its likelihood function is defined as: \deqn{p(x = k) = \frac{{K \choose k} {N - K \choose n - k}}{{N \choose n}}} The conjugate \emph{beta-binomial(\eqn{\alpha, \beta})} prior (Dyer and Pierce, 1993) has probability density function: \deqn{f(k | n, \alpha, \beta) = {n \choose k} \frac{B(k + \alpha, n - k + \beta)}{B(\alpha, \beta)}} }
 #' }
 #'
+#' @details This section elaborates on the available methods for constructing a prior distribution.
+#'
 #' \itemize{
 #'  \item{\code{none}:              This method constructs a prior distribution according to the principle of minimum information.}
 #'  \item{\code{median}:            This method constructs a prior distribution so that the prior probabilities of tolerable and intolerable misstatement are equal.}
@@ -126,8 +129,11 @@ auditPrior <- function(confidence = 0.95, likelihood = "binomial", method = "non
 	if(likelihood == "hypergeometric" && (is.null(N) || N <= 0))
 		stop("The hypergeometric likelihood requires that you specify a positive value for the populatin size N.")
 
-	if(expectedError >= 1)
-		stop("The expected errors must be entered as a proportion.")
+	if(expectedError < 0)
+		stop("The expected errors must be zero or larger than zero.")
+
+	if(expectedError >= 1 && method != "none")
+		stop("The expected errors must be entered as a proportion to use this prior construction method.")
 
 	# Create the prior distribution depending on the specified method
 	if(method == "none"){
@@ -139,13 +145,8 @@ auditPrior <- function(confidence = 0.95, likelihood = "binomial", method = "non
 		nPlus <- planning(confidence = confidence, likelihood = likelihood, expectedError = expectedError, N = N, materiality = materiality, prior = TRUE)$sampleSize
 		alpha <- (1 - confidence) / (ir * cr)
 		nMin <- planning(confidence = 1 - alpha, likelihood = likelihood, expectedError = expectedError, N = N, materiality = materiality, prior = TRUE)$sampleSize
-		if(expectedError >= 0 && expectedError < 1){
-			kPlus <- nPlus * expectedError
-			kMin <-  nMin * expectedError
-		} else {
-			kPlus <- expectedError
-			kMin <- expectedError
-		}
+		kPlus <- nPlus * expectedError
+		kMin <-  nMin * expectedError
 		nPrior <- nPlus - nMin
 		kPrior <- kPlus - kMin
 	} else if(method == "median"){
@@ -183,10 +184,10 @@ auditPrior <- function(confidence = 0.95, likelihood = "binomial", method = "non
 			stop("The values for 'pHplus' and 'pHmin' should sum to one.")  
 		if(is.null(pHplus) && !is.null(pHmin)){
 			probH1 <- 1 - pHmin
-		} else{
+		} else {
 			probH1 <- pHplus
 		}
-			probH0 <- 1 - probH1
+		probH0 <- 1 - probH1
 		if(expectedError != 0)
 			stop("Expected errors are not supported for method = 'hypotheses'.")
 		nPrior <- switch(likelihood, "poisson" = -(log(probH1) / materiality), "binomial" = log(probH1) / log(1 - materiality) - 1)
